pub struct FormatMappings(/* private fields */);Expand description
Additional format mappings from extensions or exact filenames to formats.
This is the Rust API counterpart of the CLI --formats-exts and
--formats-names options.
Implementations
Sourceimpl FormatMappings
impl FormatMappings
Sourcepub fn from_pairs<I, S, V, T>(pairs: I) -> Self
pub fn from_pairs<I, S, V, T>(pairs: I) -> Self
Build mappings from (format, values) pairs.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&String, &Vec<String>)>
pub fn iter(&self) -> impl Iterator<Item = (&String, &Vec<String>)>
Iterate through (format, values) pairs.
Sourcepub fn find_format_for_value(&self, value: &str) -> Option<&str>
pub fn find_format_for_value(&self, value: &str) -> Option<&str>
Return the format mapped to an extension or exact filename.